/// <reference types="react" />
import { ClientSize, Dataset, EventListenerFn, ScrollParams, ScrollSize } from './common';
import { ScrollDirection } from './enums';
import { ScrollAxis, ScrollDirectionState } from './generics';
export declare type SetRefFn = <T = any>(ref: T) => void;
export declare type ScrollingElementRef = Required<ScrollParams>;
export declare type RegisterEventListener = {
    addEventListener: EventListenerFn;
    removeEventListener: EventListenerFn;
};
export declare type ScrollingContainerRef = {
    scrollingElement: ScrollingElementRef | null;
    registerEventListener: RegisterEventListener | null;
};
export declare type VirtualizedScrollingContainer = {
    _scrollingContainer: HTMLElement;
};
export declare type VirtualizedGrid = {
    Grid: VirtualizedScrollingContainer;
};
export declare type ElementRef = VirtualizedScrollingContainer | VirtualizedGrid | HTMLElement;
export declare type InfiniteScrollRef<T> = React.MutableRefObject<T | null>;
export declare type ScrollDirectionBooleanState = ScrollDirectionState<boolean>;
export declare type ScrollOffsetValues = Required<ScrollDirectionBooleanState>;
export declare type InfiniteScrollState = Dataset & Required<ScrollSize> & Required<ClientSize> & {
    isLoading: boolean;
    thresholdReached: ScrollDirectionBooleanState;
    computedScrollThreshold: Required<ScrollAxis<number>>;
    cleanup: (() => void)[];
};
export declare type InfiniteScrollProps = Dataset & {
    hasMore: ScrollDirectionBooleanState;
    next: (direction: ScrollDirection) => Promise<void>;
    onScroll?: (value: Required<ScrollParams>) => void;
    scrollThreshold?: number | string;
    initialScroll?: {
        top?: number;
        left?: number;
    };
    reverse?: {
        column?: boolean;
        row?: boolean;
    };
    windowScroll?: boolean;
};
export interface InfiniteScroll {
    props: InfiniteScrollProps;
    state: InfiniteScrollState;
    _scrollingContainerRef?: ScrollingContainerRef;
    setRef: SetRefFn;
    clearListeners: () => void;
    update: (props: InfiniteScrollProps) => void;
}
